==> CGAL-4.11.3-doc_html.tar.xz: doc_html/Box_intersection_d/navtreeindex0.js <==
var NAVTREEINDEX0 =
{
"Box_intersection_d_2box_grid_8cpp-example.html":[7,0],
"Box_intersection_d_2custom_box_grid_8cpp-example.html":[7,1],
"Box_intersection_d_2minimal_8cpp-example.html":[7,2],
"Box_intersection_d_2minimal_self_8cpp-example.html":[7,3],
"Box_intersection_d_2proximity_custom_box_traits_8cpp-example.html":[7,4],
"Box_intersection_d_2triangle_self_intersect_8cpp-example.html":[7,5],
"Box_intersection_d_2triangle_self_intersect_pointers_8cpp-example.html":[7,6],
"annotated.html":[6],
"citelist.html":[5],
"classBoxIntersectionBox__d.html":[1,0,0,0],
"classBoxIntersectionBox__d.html#a13ebb7de5a2646f2c120d056a8a4d720":[1,0,0,0,5],
"classBoxIntersectionBox__d.html#a4d617e8a7a6763e6f4e7abeb45ff64f1":[1,0,0,0,3],
"classBoxIntersectionBox__d.html#a5ab22427107166043880914ee4853189":[1,0,0,0,1],
"classBoxIntersectionBox__d.html#a95c10b5fd30cf40ac5d5e375a4e575d9":[1,0,0,0,4],
"classBoxIntersectionBox__d.html#aeb13e07e21368496136c1e4f6176635d":[1,0,0,0,0],
"classBoxIntersectionBox__d.html#aff3d3a232f5d9be21be71fae0332cd6b":[1,0,0,0,2],
"classBoxIntersectionTraits__d.html":[1,0,0,1],
"classBoxIntersectionTraits__d.html#a282f813d39aa175f5b2e7e1ac3cb0c0f":[1,0,0,1,3],
"classBoxIntersectionTraits__d.html#a3efe3abd0d1349acf283cf7bd6a4346a":[1,0,0,1,5],
"classBoxIntersectionTraits__d.html#a59232fea4bba468a2d45e045e65ed611":[1,0,0,1,0],
"classBoxIntersectionTraits__d.html#a85c184377fc3cb2191db1af00cd17ca7":[1,0,0,1,4],
"classBoxIntersectionTraits__d.html#a9979d8df75799bb5fbc8cf8a0b6ed90e":[1,0,0,1,2],
"classBoxIntersectionTraits__d.html#ad1ecaad4d511d572e78809e2881e7773":[1,0,0,1,6],
"classBoxIntersectionTraits__d.html#ad51c88aa686d5e0ec36ea5579bef2622":[1,0,0,1,1],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html":[1,0,1,0],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a055072fd85b7e7bc705fdfbc2162befe":[1,0,1,0,2],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a0a2ff8ef6c0d2d3ea948f96e2ab1bf4b":[1,0,1,0,0],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a1c218de00ce71af6c77428342e57745e":[1,0,1,0,16],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a24b7a6ace2f73ebccc99fec1bc2161df":[1,0,1,0,6],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a2b5d3379ccb0935dd63766c200ad86b5":[1,0,1,0,15],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a2c8fdb4ea8688d79387dc433769ac1ba":[1,0,1,0,4],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a40c4a43c61b8ee9f3d9144c0f538e874":[1,0,1,0,7],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a67a6ff9f773b021666328ea269657b2d":[1,0,1,0,8],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a7dc0227db8cb88d136d278253160a70e":[1,0,1,0,13],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a9e4fa736dd0e83972bddedfd8ca678f7":[1,0,1,0,10],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#aaaf2421edc188aa29bc2b3807c83507a":[1,0,1,0,12],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#aaf90f02deea5e5d37e5cbea938993e10":[1,0,1,0,9],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#ac40a5b81801b81fbe9d4924b4be907f3":[1,0,1,0,5],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#ace3b8807fa9ffd5d3706b424fc28e53d":[1,0,1,0,3],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#adea60734cf5b1e72d235858dedc752a2":[1,0,1,0,1],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#ae18fbdfb0e1dfee2c106720da7d199a3":[1,0,1,0,14],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#af83ac9493e5253d7a9ea266e476832a3":[1,0,1,0,11],
"classCGAL_1_1Box__intersection__d_1_1Box__traits__d.html":[1,0,1,1],
"classCGAL_1_1Box__intersection__d_1_1Box__traits__d.html#a822ff72bd00d731bcc58023263ffed8b":[1,0,1,1,0],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html":[1,0,1,2],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a1489655baff57dc3d989631f6886a608":[1,0,1,2,3],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a1acd6d22b4e29b180e42890ede7358a1":[1,0,1,2,12],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a33d881b7c12e78961c3dc1b2dadc0016":[1,0,1,2,1],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a419f6ff57650d8ae7f55510eba8ddeae":[1,0,1,2,2],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a43cb1638da3d2f00c0c4d14d8c8da568":[1,0,1,2,15],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a685d05e838edbfcfe6e67c490957b184":[1,0,1,2,6],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a6e70ca2b0e83512149b64abe21ea0551":[1,0,1,2,0],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a71631e1284207fca0264011d6fb2c5e1":[1,0,1,2,4],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a7c94db783fb9ed1fea607a5c4a9c1916":[1,0,1,2,11],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a8342ca843e2d0dce3599c711211557e9":[1,0,1,2,8],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#aa65feaf5500d3226d857ec0b6f493982":[1,0,1,2,13],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#aae510af0b695d1defbb8d643b6f0385f":[1,0,1,2,14],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#ad3540111674ea618144d6e6af305895b":[1,0,1,2,5],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#ae231cc72443b59b9dcef50e00cca1f2a":[1,0,1,2,9],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#aecb430248957f741c801af981e8368c3":[1,0,1,2,7],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#afcbedb0de5d7349ff24a39e46ab3dde1":[1,0,1,2,10],
"examples.html":[7],
"group__PkgBoxIntersectionD.html":[1,0],
"group__PkgBoxIntersectionDClasses.html":[1,0,1],
"group__PkgBoxIntersectionDConcepts.html":[1,0,0],
"group__PkgBoxIntersectionD__box__intersection__all__pairs__d.html":[1,0,3],
"group__PkgBoxIntersectionD__box__intersection__all__pairs__d.html#ga09f0b8fe6b542d08108ec8ab053eca3e":[1,0,3,1],
"group__PkgBoxIntersectionD__box__intersection__all__pairs__d.html#gad70a513b6d48e5287fecad775055d514":[1,0,3,0],
"group__PkgBoxIntersectionD__box__intersection__d.html":[1,0,2],
"group__PkgBoxIntersectionD__box__intersection__d.html#ga5526579aad16bc9c3ed830dd8fc58f6a":[1,0,2,0],
"group__PkgBoxIntersectionD__box__intersection__d.html#ga8d0c33bc98dc6e45bc2e49e8c3fc0cee":[1,0,2,1],
"group__PkgBoxIntersectionD__box__self__intersection__all__pairs__d.html":[1,0,5],
"group__PkgBoxIntersectionD__box__self__intersection__all__pairs__d.html#ga5e1f7dfe697fd2c622bb8c8db7ece452":[1,0,5,1],
"group__PkgBoxIntersectionD__box__self__intersection__all__pairs__d.html#ga8aa29688ec201c07f9a9db15e793f920":[1,0,5,0],
"group__PkgBoxIntersectionD__box__self__intersection__d.html":[1,0,4],
"group__PkgBoxIntersectionD__box__self__intersection__d.html#ga3eed2bdb2a9e49a3fac1bca900087ec7":[1,0,4,0],
"group__PkgBoxIntersectionD__box__self__intersection__d.html#gab7247de0821618add6d68ede478528b9":[1,0,4,1],
"hasModels.html":[4],
"index.html":[],
"index.html":[0],
"index.html#Box_intersection_dDesign":[0,10],
"index.html#Box_intersection_dExample_1":[0,4],
"index.html#Box_intersection_dExample_2":[0,5],
"index.html#Box_intersection_dExample_3":[0,8],
"index.html#Box_intersection_dIntroduction":[0,0],
"index.html#Box_intersection_dSoftware":[0,2],
"index.html#secbox_inters_example_proximity":[0,9],
"index.html#secboxintersdef":[0,1],
"index.html#secboxintersectminimal":[0,3],
"index.html#secboxintersparams":[0,6],
"index.html#secboxintersperformance":[0,7],
"models.html":[3],
"modules.html":[1],
"namespaceCGAL.html":[6,1],
"namespaceCGAL_1_1Box__intersection__d.html":[6,1,0],
"namespaceboost.html":[6,0],
"pages.html":[],
"refines.html":[2]
};

==> CGAL-5.4.1-doc_html.tar.xz: doc_html/Box_intersection_d/navtreeindex0.js <==
var NAVTREEINDEX0 =
{
"Box_intersection_d_2box_d_do_intersect_polylines_8cpp-example.html":[7,0],
"Box_intersection_d_2box_grid_8cpp-example.html":[7,1],
"Box_intersection_d_2custom_box_grid_8cpp-example.html":[7,2],
"Box_intersection_d_2minimal_8cpp-example.html":[7,3],
"Box_intersection_d_2minimal_self_8cpp-example.html":[7,4],
"Box_intersection_d_2proximity_custom_box_traits_8cpp-example.html":[7,5],
"Box_intersection_d_2triangle_self_intersect_8cpp-example.html":[7,6],
"Box_intersection_d_2triangle_self_intersect_pointers_8cpp-example.html":[7,7],
"annotated.html":[6],
"citelist.html":[5],
"classBoxIntersectionBox__d.html":[1,0,0,0],
"classBoxIntersectionBox__d.html#a1ea0d2c1d83dc5d7106d951aae639db0":[1,0,0,0,4],
"classBoxIntersectionBox__d.html#a5ab22427107166043880914ee4853189":[1,0,0,0,1],
"classBoxIntersectionBox__d.html#a95b4606887a86c225ac3c4b8613e3434":[1,0,0,0,5],
"classBoxIntersectionBox__d.html#acd16f709ab7da6cb79780c095bd8ae5f":[1,0,0,0,3],
"classBoxIntersectionBox__d.html#aeb13e07e21368496136c1e4f6176635d":[1,0,0,0,0],
"classBoxIntersectionBox__d.html#aff3d3a232f5d9be21be71fae0332cd6b":[1,0,0,0,2],
"classBoxIntersectionTraits__d.html":[1,0,0,1],
"classBoxIntersectionTraits__d.html#a282f813d39aa175f5b2e7e1ac3cb0c0f":[1,0,0,1,3],
"classBoxIntersectionTraits__d.html#a3efe3abd0d1349acf283cf7bd6a4346a":[1,0,0,1,5],
"classBoxIntersectionTraits__d.html#a59232fea4bba468a2d45e045e65ed611":[1,0,0,1,0],
"classBoxIntersectionTraits__d.html#a85c184377fc3cb2191db1af00cd17ca7":[1,0,0,1,4],
"classBoxIntersectionTraits__d.html#a9979d8df75799bb5fbc8cf8a0b6ed90e":[1,0,0,1,2],
"classBoxIntersectionTraits__d.html#ad1ecaad4d511d572e78809e2881e7773":[1,0,0,1,6],
"classBoxIntersectionTraits__d.html#ad51c88aa686d5e0ec36ea5579bef2622":[1,0,0,1,1],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html":[1,0,1,0],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a055072fd85b7e7bc705fdfbc2162befe":[1,0,1,0,2],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a06781897a18764129061c222ff90bddf":[1,0,1,0,16],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a0a2ff8ef6c0d2d3ea948f96e2ab1bf4b":[1,0,1,0,0],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a24b7a6ace2f73ebccc99fec1bc2161df":[1,0,1,0,6],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a2c8fdb4ea8688d79387dc433769ac1ba":[1,0,1,0,4],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a4c78a1641066644cebc5301b0da91291":[1,0,1,0,7],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a69d02669e7c13169c82e3e0ef3e2e103":[1,0,1,0,15],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a7dc0227db8cb88d136d278253160a70e":[1,0,1,0,13],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#a9e4fa736dd0e83972bddedfd8ca678f7":[1,0,1,0,10],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#aaaf2421edc188aa29bc2b3807c83507a":[1,0,1,0,12],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#aaf90f02deea5e5d37e5cbea938993e10":[1,0,1,0,9],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#ac40a5b81801b81fbe9d4924b4be907f3":[1,0,1,0,5],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#ace3b8807fa9ffd5d3706b424fc28e53d":[1,0,1,0,3],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#ad67c9be494370f68192b153717044404":[1,0,1,0,8],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#adea60734cf5b1e72d235858dedc752a2":[1,0,1,0,1],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#ae18fbdfb0e1dfee2c106720da7d199a3":[1,0,1,0,14],
"classCGAL_1_1Box__intersection__d_1_1Box__d.html#af83ac9493e5253d7a9ea266e476832a3":[1,0,1,0,11],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html":[1,0,1,2],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a08643e805c95367c1cc380ea76016923":[1,0,1,2,7],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a12b2eb3f122e119918fb401587608e8c":[1,0,1,2,8],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a1489655baff57dc3d989631f6886a608":[1,0,1,2,3],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a1acd6d22b4e29b180e42890ede7358a1":[1,0,1,2,12],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a33d881b7c12e78961c3dc1b2dadc0016":[1,0,1,2,1],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a419f6ff57650d8ae7f55510eba8ddeae":[1,0,1,2,2],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a685d05e838edbfcfe6e67c490957b184":[1,0,1,2,6],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a6e70ca2b0e83512149b64abe21ea0551":[1,0,1,2,0],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a71631e1284207fca0264011d6fb2c5e1":[1,0,1,2,4],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a8d0e71d7a688db452289e6da1d7f26ee":[1,0,1,2,11],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#a9c35f97c8f9a10218d18ef566a4fc809":[1,0,1,2,15],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#aa65feaf5500d3226d857ec0b6f493982":[1,0,1,2,13],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#ad3540111674ea618144d6e6af305895b":[1,0,1,2,5],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#ae231cc72443b59b9dcef50e00cca1f2a":[1,0,1,2,9],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#aedf043a7af9e184811110192dae2b51d":[1,0,1,2,14],
"classCGAL_1_1Box__intersection__d_1_1Box__with__handle__d.html#afcbedb0de5d7349ff24a39e46ab3dde1":[1,0,1,2,10],
"examples.html":[7],
"group__PkgBoxIntersectionDClasses.html":[1,0,1],
"group__PkgBoxIntersectionDConcepts.html":[1,0,0],
"group__PkgBoxIntersectionDRef.html":[1,0],
"group__PkgBoxIntersectionD__box__intersection__all__pairs__d.html":[1,0,3],
"group__PkgBoxIntersectionD__box__intersection__all__pairs__d.html#ga09f0b8fe6b542d08108ec8ab053eca3e":[1,0,3,1],
"group__PkgBoxIntersectionD__box__intersection__all__pairs__d.html#gad70a513b6d48e5287fecad775055d514":[1,0,3,0],
"group__PkgBoxIntersectionD__box__intersection__d.html":[1,0,2],
"group__PkgBoxIntersectionD__box__intersection__d.html#ga7ac96673d25a437c98e8abb864a3362d":[1,0,2,0],
"group__PkgBoxIntersectionD__box__intersection__d.html#gada6480fdd5fe227490d3f439c2653db6":[1,0,2,1],
"group__PkgBoxIntersectionD__box__self__intersection__all__pairs__d.html":[1,0,5],
"group__PkgBoxIntersectionD__box__self__intersection__all__pairs__d.html#ga5e1f7dfe697fd2c622bb8c8db7ece452":[1,0,5,1],
"group__PkgBoxIntersectionD__box__self__intersection__all__pairs__d.html#ga8aa29688ec201c07f9a9db15e793f920":[1,0,5,0],
"group__PkgBoxIntersectionD__box__self__intersection__d.html":[1,0,4],
"group__PkgBoxIntersectionD__box__self__intersection__d.html#gab7247de0821618add6d68ede478528b9":[1,0,4,1],
"group__PkgBoxIntersectionD__box__self__intersection__d.html#gafd815640c2f3774c0da5a9374c09a824":[1,0,4,0],
"hasModels.html":[4],
"index.html":[0],
"index.html":[],
"index.html#Box_intersection_dDesign":[0,11],
"index.html#Box_intersection_dExample_1":[0,4],
"index.html#Box_intersection_dExample_2":[0,5],
"index.html#Box_intersection_dExample_3":[0,8],
"index.html#Box_intersection_dIntroduction":[0,0],
"index.html#Box_intersection_dSoftware":[0,2],
"index.html#secbox_inters_example_polylines":[0,10],
"index.html#secbox_inters_example_proximity":[0,9],
"index.html#secboxintersdef":[0,1],
"index.html#secboxintersectminimal":[0,3],
"index.html#secboxintersparams":[0,6],
"index.html#secboxintersperformance":[0,7],
"models.html":[3],
"modules.html":[1],
"namespaceCGAL.html":[6,0],
"namespaceCGAL_1_1Box__intersection__d.html":[6,0,0],
"pages.html":[],
"refines.html":[2],
"structCGAL_1_1Box__intersection__d_1_1Box__traits__d.html":[1,0,1,1],
"structCGAL_1_1Box__intersection__d_1_1Box__traits__d.html#a822ff72bd00d731bcc58023263ffed8b":[1,0,1,1,0]
};
